==> jc-1.4.0.tar.gz: gnu/java/nio/ChannelOutputStream.h <==
// public final class gnu.java.nio.ChannelOutputStream

// class file dependencies
// @dep_class dc5f72200f8c3fe gnu_java_nio_ChannelOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_java_nio_ChannelOutputStream_H_
#define _JC_gnu_java_nio_ChannelOutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_WritableByteChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ChannelOutputStream$sub_refs	_jc_gnu_java_nio_ChannelOutputStream$sub_refs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs	_jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$refs	_jc_gnu_java_nio_ChannelOutputStream$refs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$nonrefs	_jc_gnu_java_nio_ChannelOutputStream$nonrefs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$object	_jc_gnu_java_nio_ChannelOutputStream$object;

typedef const struct _jc_gnu_java_nio_ChannelOutputStream$vmethods	_jc_gnu_java_nio_ChannelOutputStream$vmethods;
typedef const struct _jc_gnu_java_nio_ChannelOutputStream$vtable	_jc_gnu_java_nio_ChannelOutputStream$vtable;
typedef const struct _jc_gnu_java_nio_ChannelOutputStream$vtype	_jc_gnu_java_nio_ChannelOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_nio_ChannelOutputStream$method$_init$7395dac4c82e9f4d(_jc_env *, struct _jc_gnu_java_nio_ChannelOutputStream$object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_java_nio_ChannelOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_nio_ChannelOutputStream$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ChannelOutputStream$method_info$write$6377ac6964854eb2;

// Virtual methods structure
struct _jc_gnu_java_nio_ChannelOutputStream$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_nio_ChannelOutputStream$object *, jint);
};

// Vtable
struct _jc_gnu_java_nio_ChannelOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_java_nio_ChannelOutputStream$vmethods	gnu_java_nio_ChannelOutputStream;
};

// Vtype
struct _jc_gnu_java_nio_ChannelOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ChannelOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelOutputStream$sub_refs {
	struct _jc_object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ChannelOutputStream$refs {
    _jc_gnu_java_nio_ChannelOutputStream$sub_refs	gnu_java_nio_ChannelOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ChannelOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs	gnu_java_nio_ChannelOutputStream;
};

// Object instance structure
struct _jc_gnu_java_nio_ChannelOutputStream$object {
	_jc_gnu_java_nio_ChannelOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ChannelOutputStream$vtype	*vtype;
	_jc_gnu_java_nio_ChannelOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ChannelOutputStream$vtype _jc_gnu_java_nio_ChannelOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ChannelOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ChannelOutputStream$class_object;

#endif	/* _JC_gnu_java_nio_ChannelOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/ChannelOutputStream.h <==
// public final class gnu.java.nio.ChannelOutputStream

// class file dependencies
// @dep_class dc5f72200f8c3fe gnu_java_nio_ChannelOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_java_nio_ChannelOutputStream_H_
#define _JC_gnu_java_nio_ChannelOutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_WritableByteChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ChannelOutputStream$sub_refs	_jc_gnu_java_nio_ChannelOutputStream$sub_refs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs	_jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$refs	_jc_gnu_java_nio_ChannelOutputStream$refs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$nonrefs	_jc_gnu_java_nio_ChannelOutputStream$nonrefs;
typedef struct _jc_gnu_java_nio_ChannelOutputStream$object	_jc_gnu_java_nio_ChannelOutputStream$object;

typedef const struct _jc_gnu_java_nio_ChannelOutputStream$vmethods	_jc_gnu_java_nio_ChannelOutputStream$vmethods;
typedef const struct _jc_gnu_java_nio_ChannelOutputStream$vtable	_jc_gnu_java_nio_ChannelOutputStream$vtable;
typedef const struct _jc_gnu_java_nio_ChannelOutputStream$vtype	_jc_gnu_java_nio_ChannelOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_nio_ChannelOutputStream$method$_init$7395dac4c82e9f4d(_jc_env *, struct _jc_gnu_java_nio_ChannelOutputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_nio_ChannelOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_nio_ChannelOutputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ChannelOutputStream$method_info$write$6377ac6964854eb2;

// Virtual methods structure
struct _jc_gnu_java_nio_ChannelOutputStream$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_nio_ChannelOutputStream$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_ChannelOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_java_nio_ChannelOutputStream$vmethods	gnu_java_nio_ChannelOutputStream;
};

// Vtype
struct _jc_gnu_java_nio_ChannelOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ChannelOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelOutputStream$sub_refs {
	struct _jc_object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ChannelOutputStream$refs {
    _jc_gnu_java_nio_ChannelOutputStream$sub_refs	gnu_java_nio_ChannelOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ChannelOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_java_nio_ChannelOutputStream$sub_nonrefs	gnu_java_nio_ChannelOutputStream;
};

// Object instance structure
struct _jc_gnu_java_nio_ChannelOutputStream$object {
	_jc_gnu_java_nio_ChannelOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ChannelOutputStream$vtype	*vtype;
	_jc_gnu_java_nio_ChannelOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ChannelOutputStream$vtype _jc_gnu_java_nio_ChannelOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ChannelOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ChannelOutputStream$class_object;

#endif	/* _JC_gnu_java_nio_ChannelOutputStream_H_ */
